import fetch from 'isomorphic-fetch';

const opts = {};

function myFetch(url, opt) {
  return new Promise(async (resolve, reject) => {
    try {
      const result = await fetch(url, opt);
      resolve(result.json());
    } catch (e) {
      reject(e);
    }
  });
}

async function $fetch(url, option = {}) {
  const result = myFetch(url, option);
  const handle = opts.filter(result);
  return handle ? handle : result;
}

async function $get(url) {
  const getOpts = Object.assign({
    method: 'GET'
  }, opts);
  const result = await myFetch(`${url}?t=${+new Date()}`, getOpts);
  const handle = opts.filter(result);
  return handle ? handle : result;
}

async function $post(url, data) {
  const postOpts = Object.assign({
    method: 'POST'
  }, opts);
  if (data) {
    postOpts.body = JSON.stringify(data);
  }
  const result = await myFetch(url, postOpts);
  const handle = opts.filter(result);
  return handle ? handle : result;
}

export default {
  fetch: $fetch,
  get: $get,
  post: $post,
  install: (Vue, options) => {
    Object.assign(opts, options);
    Vue.mixin({
      methods: {
        $fetch,
        $get,
        $post
      }
    });
  }
};
